/*
 * Copyright (c) 2015-2016 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice and this list of conditions.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice and  this list of  conditions in the  documentation and/or
 *      other materials provided with the distribution.
 *
 *                                      Anthony Mallet on Mon Aug 24 2015
 */
#include "acpom.h"

#include <cstdio>

#include "pom_c_types.h"
#include "codels.h"


/* --- Function log ----------------------------------------------------- */

/** Codel pom_log_start of function log.
 *
 * Returns genom_ok.
 * Throws pom_e_sys.
 */
genom_event
pom_log_start(const char path[64], pom_log_s **log,
              genom_context self)
{
  FILE *f;

  pom_log_stop(log, self);

  f = fopen(path, "w");
  if (!f) return pom_e_sys_error(path, self);
  fprintf(f, pom_log_header "\n");

  *log = new pom_log_s;
  if (!*log) {
    fclose(f);
    unlink(path);
    errno = ENOMEM;
    return pom_e_sys_error("log", self);
  }

  (*log)->logf = f;
  return genom_ok;
}


/* --- Function log_stop ------------------------------------------------ */

/** Codel pom_log_stop of function log_stop.
 *
 * Returns genom_ok.
 */
genom_event
pom_log_stop(pom_log_s **log, genom_context self)
{
  if (!*log) return genom_ok;

  fclose((*log)->logf);
  delete *log;
  *log = NULL;
  return genom_ok;
}
